==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/WebMaskInputBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
/**
 * @hidden
 */
var WebMaskInputBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebMaskInputBaseDescriptionMetadata, _super);
    function WebMaskInputBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMaskInputBaseDescriptionMetadata.b = function (a) {
        if (WebMaskInputBaseDescriptionMetadata.a == null) {
            WebMaskInputBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMaskInputBaseDescriptionMetadata.c(WebMaskInputBaseDescriptionMetadata.a);
        }
        if (a.g(WebMaskInputBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(WebMaskInputBaseDescriptionMetadata.a);
    };
    WebMaskInputBaseDescriptionMetadata.c = function (a) {
        WebInputBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:MaskInputBase");
        a.item("Prompt", "String");
        a.item("Invalid", "Boolean");
    };
    WebMaskInputBaseDescriptionMetadata.d = function (a) {
        WebMaskInputBaseDescriptionMetadata.b(a);
        a.t("WebMaskInputBase", WebMaskInputBaseDescriptionMetadata.a);
    };
    WebMaskInputBaseDescriptionMetadata.$t = markType(WebMaskInputBaseDescriptionMetadata, 'WebMaskInputBaseDescriptionMetadata');
    WebMaskInputBaseDescriptionMetadata.a = null;
    return WebMaskInputBaseDescriptionMetadata;
}(Base));
export { WebMaskInputBaseDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebMaskInputBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebInputBaseDescriptionMetadata } from "./WebInputBaseDescriptionMetadata";
/**
 * @hidden
 */
var WebMaskInputBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebMaskInputBaseDescriptionMetadata, _super);
    function WebMaskInputBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebMaskInputBaseDescriptionMetadata.b = function (a) {
        if (WebMaskInputBaseDescriptionMetadata.a == null) {
            WebMaskInputBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebMaskInputBaseDescriptionMetadata.c(WebMaskInputBaseDescriptionMetadata.a);
        }
        if (a.j(WebMaskInputBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(WebMaskInputBaseDescriptionMetadata.a);
    };
    WebMaskInputBaseDescriptionMetadata.c = function (a) {
        WebInputBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:MaskInputBase");
        a.item("Prompt", "String");
        a.item("Invalid", "Boolean");
    };
    WebMaskInputBaseDescriptionMetadata.d = function (a) {
        WebMaskInputBaseDescriptionMetadata.b(a);
        a.z("WebMaskInputBase", WebMaskInputBaseDescriptionMetadata.a);
    };
    WebMaskInputBaseDescriptionMetadata.$t = markType(WebMaskInputBaseDescriptionMetadata, 'WebMaskInputBaseDescriptionMetadata');
    WebMaskInputBaseDescriptionMetadata.a = null;
    return WebMaskInputBaseDescriptionMetadata;
}(Base));
export { WebMaskInputBaseDescriptionMetadata };
